@@ -19,8 +19,12 @@ from .util import logger, wait_until_port_is_open
 
 
 @lru_cache()
-def _get_ec2_client(region):
-    return boto3.client("ec2", region_name=region)
+def _get_ec2_client(region, *, profile_name: str):
+    session = boto3.Session(profile_name=profile_name)
+    return session.client(
+        "ec2", 
+        region_name=region, 
+    )
 
 
 class InstanceProvider:
@@ -98,6 +102,7 @@ class AWSInstanceProvider(InstanceProvider):
         instance_ami: Optional[str],
         ssh_key_pair_name: str,
         volume_size: int,
+        credentials_profile_name: str,
         **kwargs,
     ):
         super().__init__(**kwargs)
@@ -108,10 +113,14 @@ class AWSInstanceProvider(InstanceProvider):
         self.instance_ami = instance_ami
         self.ssh_key_pair_name = ssh_key_pair_name
         self.volume_size = volume_size
+        self.credentials_profile_name = credentials_profile_name
 
     @property
     def _ec2_client(self):
-        return _get_ec2_client(self.aws_region)
+        return _get_ec2_client(
+            self.aws_region,
+            profile_name=self.credentials_profile_name
+        )
 
     def _search_for_instances(self) -> Dict:
         return self._ec2_client.describe_instances(
@@ -200,9 +209,7 @@ class AWSInstanceProvider(InstanceProvider):
             PublicKeyMaterial=file_bytes,
         )
 
-    def _get_sceptre_plan(self) -> SceptrePlan:
-        if self.instance_ami != None:
-            logger.info(f"Creating with {self.instance_ami }")    
+    def _get_sceptre_plan(self) -> SceptrePlan:  
         context = SceptreContext(
             SCEPTRE_PATH,
             "dev/application.yaml",
@@ -257,11 +264,11 @@ class AWSInstanceProvider(InstanceProvider):
         && sudo echo GRUB_CMDLINE_LINUX=\\"\"cdgroup_enable=memory swapaccount=1\\"\" | sudo tee -a /etc/default/grub.d/50-cloudimg-settings.cfg
         && sudo update-grub
         && sudo apt-get -y update
-        && sudo apt-get -y install docker.io
-        && sudo usermod -aG docker ubuntu
-        && sudo systemctl daemon-reload
-        && sudo systemctl restart docker.service
-        && sudo systemctl enable docker.service
+        && sudo apt-get -y install docker.io || true
+        && sudo usermod -aG docker ubuntu  || true
+        && sudo systemctl daemon-reload || true
+        && sudo systemctl restart docker.service || true
+        && sudo systemctl enable docker.service || true
         && "sudo sed -i -e '/GatewayPorts/ s/^.*$/GatewayPorts yes/' '/etc/ssh/sshd_config'"
         && sudo service sshd restart
         && wget -qO- https://github.com/bcpierce00/unison/releases/download/v2.52.1/unison-v2.52.1+ocaml-4.01.0+x86_64.linux.tar.gz | tar -xvz
